<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>MainMenu</name>
    <message>
        <location filename="../menu/mainmenu.cpp" line="57"/>
        <source>Play</source>
        <translation>Gioca</translation>
    </message>
    <message>
        <location filename="../menu/mainmenu.cpp" line="61"/>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <location filename="../menu/mainmenu.cpp" line="65"/>
        <source>Credits</source>
        <translation>Riconoscimenti</translation>
    </message>
    <message>
        <location filename="../menu/mainmenu.cpp" line="69"/>
        <source>Quit</source>
        <translation>Esci</translation>
    </message>
    <message>
        <location filename="../menu/mainmenu.cpp" line="77"/>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../menu/help.cpp" line="31"/>
        <source>GAME GOAL

You are racing against eleven
computer players.

Your best position will be
the next start position.

Finish in TOP-6 to unlock
a new race track!

CONTROLS FOR PLAYER 1

Turn left  : Left
Turn right : Right
Accelerate : Up / RIGHT SHIFT
Brake      : Down / RIGHT CTRL

CONTROLS FOR PLAYER 2

Turn left  : A
Turn right : D
Accelerate : W / LEFT SHIFT
Brake      : S / LEFT CTRL

Quit       : ESC/Q
Pause      : P</source>
        <translation>OBIETTIVO DEL GIOCO

Corri contro undici giocatori
controllati dal computer.

La tua migliore posizione
sarà quella della partenza
successiva.

Arriva tra i primi 6 per
sbloccare un nuovo tracciato!

CONTROLLI GIOCATORE 1
Gira a sinistra  : Sinistra
Gira a destra    : Destra
Accelera   : Su / MAIUSC DESTRO
Frena      : Giù / CTRL DESTRO

CONTROLLI GIOCATORE 2
Gira a sinistra  : A
Gira a destra    : D
Accelera   : W / MAIUSC SINISTRO
Frena      : S / CTRL SINISTRO

Esci       : ESC/Q
Pause      : P</translation>
    </message>
    <message>
        <location filename="../menu/keyconfigmenu.cpp" line="49"/>
        <source>Press a key..</source>
        <translation>Premi un tasto..</translation>
    </message>
    <message>
        <location filename="../menu/keyconfigmenu.cpp" line="89"/>
        <source>Player One Accelerate</source>
        <translation>Giocatore 1 accelera</translation>
    </message>
    <message>
        <location filename="../menu/keyconfigmenu.cpp" line="98"/>
        <source>Player One Brake</source>
        <translation>Giocatore 1 frena</translation>
    </message>
    <message>
        <location filename="../menu/keyconfigmenu.cpp" line="107"/>
        <source>Player One Turn Left</source>
        <translation>Giocatore 1 gira a sinistra</translation>
    </message>
    <message>
        <location filename="../menu/keyconfigmenu.cpp" line="116"/>
        <source>Player One Turn Right</source>
        <translation>Giocatore 1 gira a destra</translation>
    </message>
    <message>
        <location filename="../menu/keyconfigmenu.cpp" line="138"/>
        <source>Player Two Accelerate</source>
        <translation>Giocatore 2 accelera</translation>
    </message>
    <message>
        <location filename="../menu/keyconfigmenu.cpp" line="147"/>
        <source>Player Two Brake</source>
        <translation>Giocatore 2 frena</translation>
    </message>
    <message>
        <location filename="../menu/keyconfigmenu.cpp" line="156"/>
        <source>Player Two Turn Left</source>
        <translation>Giocatore 2 gira a sinistra</translation>
    </message>
    <message>
        <location filename="../menu/keyconfigmenu.cpp" line="165"/>
        <source>Player Two Turn Right</source>
        <translation>Giocatore 2 gira a destra</translation>
    </message>
    <message>
        <source>At least OpenGL ES 2.0 is required!</source>
        <translation type="obsolete">È richiesta almeno OpenGL ES 2.0!</translation>
    </message>
    <message>
        <source>Cannot start Dust Racing 2D</source>
        <translation type="obsolete">Impossibile avviare Dust Racing 2D</translation>
    </message>
    <message>
        <source>At least OpenGL 3.0 is required!</source>
        <translation type="obsolete">È richiesta almeno OpenGL 3.0!</translation>
    </message>
    <message>
        <source>At least OpenGL 2.1 is required!</source>
        <translation type="obsolete">È richiesta almeno OpenGL 2.1!</translation>
    </message>
    <message>
        <location filename="../race.cpp" line="347"/>
        <source>The Time Trial has ended!</source>
        <translation>La prova cronometrata è terminata!</translation>
    </message>
    <message>
        <location filename="../race.cpp" line="351"/>
        <source>The winner has finished!</source>
        <translation>Il vincitore è arrivato!</translation>
    </message>
    <message>
        <location filename="../race.cpp" line="69"/>
        <source>New lap record!</source>
        <translation>Nuovo record sul giro!</translation>
    </message>
    <message>
        <location filename="../race.cpp" line="76"/>
        <source>New race record!</source>
        <translation>Nuovo record sul giro!</translation>
    </message>
    <message>
        <location filename="../race.cpp" line="376"/>
        <source>Pit stop!</source>
        <translation>Pit stop!</translation>
    </message>
    <message>
        <location filename="../race.cpp" line="569"/>
        <source>A new best pos!</source>
        <translation>Nuova migliore posizione!</translation>
    </message>
    <message>
        <location filename="../race.cpp" line="579"/>
        <source>A new track unlocked!</source>
        <translation>Nuovo tracciato sbloccato!</translation>
    </message>
    <message>
        <location filename="../race.cpp" line="583"/>
        <source>Better luck next time..</source>
        <translation>La prossima volta sarai più fortunato..</translation>
    </message>
    <message>
        <location filename="../race.cpp" line="626"/>
        <source>You must stay on track!</source>
        <translation>Devi rimanere sul tracciato!</translation>
    </message>
    <message>
        <location filename="../race.cpp" line="630"/>
        <source>Watch your tires!</source>
        <translation>Controlla le gomme!</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="78"/>
        <source>Reset best positions?</source>
        <translation>Azzerare migliori posizioni?</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="89"/>
        <source>Reset record times?</source>
        <translation>Azzerare tempi record?</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="101"/>
        <source>Reset unlocked tracks?</source>
        <translation>Azzerare tracciati sbloccati?</translation>
    </message>
    <message>
        <source>Difficulty &gt;</source>
        <translation type="obsolete">Difficoltà &gt;</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="204"/>
        <source>Sounds &gt;</source>
        <translation>Audio &gt;</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="208"/>
        <source>GFX &gt;</source>
        <translation>GRAFICA &gt;</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="216"/>
        <source>Reset &gt;</source>
        <translation>Reset &gt;</translation>
    </message>
    <message>
        <location filename="../menu/difficultymenu.cpp" line="42"/>
        <source>Easy</source>
        <translation>Facile</translation>
    </message>
    <message>
        <location filename="../menu/difficultymenu.cpp" line="52"/>
        <source>Medium</source>
        <translation>Medio</translation>
    </message>
    <message>
        <location filename="../menu/difficultymenu.cpp" line="62"/>
        <source>Hard</source>
        <translation>Difficile</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="374"/>
        <source>VSync &gt;</source>
        <translation>VSync &gt;</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="393"/>
        <location filename="../menu/vsyncmenu.cpp" line="99"/>
        <source>Off</source>
        <translation>Disattivato</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="405"/>
        <location filename="../menu/vsyncmenu.cpp" line="103"/>
        <source>On</source>
        <translation>Attivato</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="435"/>
        <source>Reset record times</source>
        <translation>Azzera tempi record</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="439"/>
        <source>Reset best positions</source>
        <translation>Azzera migliori posizioni</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="443"/>
        <source>Reset unlocked tracks</source>
        <translation>Azzera tracciati sbloccati</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="358"/>
        <source>Full screen resolution &gt;</source>
        <translation>Risoluzione a schermo intero &gt;</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="362"/>
        <source>Windowed resolution &gt;</source>
        <translation>Risoluzione in finestra &gt;</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="366"/>
        <source>FPS &gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="370"/>
        <source>Split type &gt;</source>
        <translation>Divisione schermo &gt;</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="200"/>
        <source>Game mode &gt;</source>
        <translation>Modalità di gioco &gt;</translation>
    </message>
    <message>
        <source>Lap Count &gt;</source>
        <translation type="obsolete">Numero di giri &gt;</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="212"/>
        <source>Controls &gt;</source>
        <translation>Configurazione tasti &gt;</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="236"/>
        <source>30 fps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="246"/>
        <source>60 fps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="277"/>
        <source>Two player race</source>
        <translation>Gareggia con due giocatori</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="286"/>
        <source>One player race</source>
        <translation>Gareggia con un giocatore</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="295"/>
        <source>Time Trial</source>
        <translation>Prova cronometrata</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="304"/>
        <source>Duel</source>
        <translation>Duello</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="328"/>
        <source>Vertical</source>
        <translation>Verticale</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="337"/>
        <source>Horizontal</source>
        <translation>Orizzontale</translation>
    </message>
    <message>
        <location filename="../startlights.cpp" line="135"/>
        <source>GO!!!</source>
        <translation>VIA!!!</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="52"/>
        <source>---</source>
        <translation>---</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="53"/>
        <source>1st</source>
        <translation>1.</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="54"/>
        <source>2nd</source>
        <translation>2.</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="55"/>
        <source>3rd</source>
        <translation>3.</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="56"/>
        <source>4th</source>
        <translation>4.</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="57"/>
        <source>5th</source>
        <translation>5.</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="58"/>
        <source>6th</source>
        <translation>6.</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="59"/>
        <source>7th</source>
        <translation>7.</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="60"/>
        <source>8th</source>
        <translation>8.</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="61"/>
        <source>9th</source>
        <translation>9.</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="62"/>
        <source>10th</source>
        <translation>10.</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="63"/>
        <source>11th</source>
        <translation>11.</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="64"/>
        <source>12th</source>
        <translation>12.</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="185"/>
        <source> LAP:</source>
        <translation> GIRO:</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="202"/>
        <source> POS:</source>
        <extracomment>Position/rank</extracomment>
        <translation> POS:</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="210"/>
        <source>LAP</source>
        <translation>GIRO</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="210"/>
        <source>LAPS</source>
        <translation>GIRI</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="247"/>
        <source> KM/H</source>
        <translation> KM/H</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="260"/>
        <source>LAP:</source>
        <translation>GIRO:</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="306"/>
        <source>L:</source>
        <extracomment>Last lap time</extracomment>
        <translation>G:</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="326"/>
        <source>R:</source>
        <extracomment>Lap record time</extracomment>
        <translation>R:</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="347"/>
        <source>TOT:</source>
        <extracomment>Total race time</extracomment>
        <translation>TOT:</translation>
    </message>
    <message>
        <location filename="../menu/trackselectionmenu.cpp" line="266"/>
        <source>       Laps: </source>
        <translation>       Giri: </translation>
    </message>
    <message>
        <location filename="../menu/trackselectionmenu.cpp" line="273"/>
        <source>     Length: </source>
        <translation>     Lunghezza: </translation>
    </message>
    <message>
        <location filename="../menu/trackselectionmenu.cpp" line="311"/>
        <source>Finish previous track in TOP-6 to unlock!</source>
        <extracomment>Try to keep the translation as short as possible.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../menu/trackselectionmenu.cpp" line="316"/>
        <source>Unlock it in one/two player race!</source>
        <extracomment>&quot;it&quot; = a locked track. Try to keep the translation as short as possible.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> m</source>
        <translation type="obsolete"> m</translation>
    </message>
    <message>
        <location filename="../menu/trackselectionmenu.cpp" line="280"/>
        <source> Lap Record: </source>
        <translation> Record sul giro: </translation>
    </message>
    <message>
        <location filename="../menu/trackselectionmenu.cpp" line="287"/>
        <source>Race Record: </source>
        <translation>Record tracciato: </translation>
    </message>
    <message>
        <source>PROGRAMMING BY</source>
        <translation type="obsolete">PROGRAMMATO DA</translation>
    </message>
    <message>
        <source>GRAPHICS BY</source>
        <translation type="obsolete">GRAFICA</translation>
    </message>
    <message>
        <source>RACE TRACKS BY</source>
        <translation type="obsolete">TRACCIATI</translation>
    </message>
    <message>
        <source>CONTRIBUTORS</source>
        <translation type="obsolete">CON IL CONTRIBUTO DI</translation>
    </message>
    <message>
        <location filename="../menu/credits.cpp" line="40"/>
        <source>PROGRAMMING</source>
        <translation>PROGRAMMAZIONE</translation>
    </message>
    <message>
        <location filename="../menu/credits.cpp" line="42"/>
        <source>GRAPHICS</source>
        <translation>GRAFICA</translation>
    </message>
    <message>
        <location filename="../menu/credits.cpp" line="44"/>
        <source>LEVEL DESIGN</source>
        <translation>PROGETTAZIONE LIVELLI</translation>
    </message>
    <message>
        <location filename="../menu/credits.cpp" line="46"/>
        <source>TRANSLATIONS</source>
        <translation>TRADUZIONI</translation>
    </message>
    <message>
        <location filename="../menu/credits.cpp" line="48"/>
        <source>PATCHES</source>
        <translation>PATCH</translation>
    </message>
    <message>
        <location filename="../menu/credits.cpp" line="50"/>
        <source>SPECIAL THANKS</source>
        <translation>RINGRAZIAMENTI SPECIALI</translation>
    </message>
    <message>
        <location filename="../menu/resolutionmenu.cpp" line="115"/>
        <source>Restart to change the resolution.</source>
        <translation>Riavvia per modificare la risoluzione.</translation>
    </message>
    <message>
        <source>Native resolution</source>
        <translation type="obsolete">Risoluzione nativa</translation>
    </message>
    <message>
        <location filename="../menu/confirmationmenu.cpp" line="31"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../menu/confirmationmenu.cpp" line="32"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../menu/vsyncmenu.cpp" line="75"/>
        <source>Restart to change VSync setting.</source>
        <translation>Riavvia per cambiare le impostazioni VSync.</translation>
    </message>
    <message>
        <location filename="../menu/lapcountmenu.cpp" line="84"/>
        <source>Choose lap count</source>
        <translation>Numero di giri</translation>
    </message>
</context>
</TS>
